==> kxmleditor-0.6.tar.gz: kxmleditor-0.6/kxmleditor/tablewidget.h <==
/***************************************************************************
                          tablewidget.h  -  description
                             -------------------
    begin                : Tue Jul 10 2001
    copyright            : (C) 2001 by Lumir Vanek
    email                : lvanek@eanet.cz
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef TABLEWIDGET_H
#define TABLEWIDGET_H

#include <qwidget.h>
#include <qtable.h>

/**Inherits for QTable and extend it
functionality
  *@author Lumir Vanek
  */

class TableWidget : public QTable
{
   Q_OBJECT
public:
	TableWidget(int, int, QWidget *parent = 0, const char *name = 0);
	~TableWidget();

protected:	
  /** Called, when mouse event occur in widget */
  virtual void contentsMousePressEvent(QMouseEvent *);	

signals: // Signals
  /** Emited, when user press rigth mouse button */
  void rightButtonPressed(const QPoint&);
};

#endif

==> kxmleditor_0.7.1.orig.tar.gz: kxmleditor-0.7.1/kxmleditor/tablewidget.h <==
/***************************************************************************
                          tablewidget.h  -  description
                             -------------------
    begin                : Tue Jul 10 2001
    copyright            : (C) 2001 by The KXMLEditor Team
    email                : lvanek@eanet.cz
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef TABLEWIDGET_H
#define TABLEWIDGET_H

#include <qtable.h>

class XmlElement;

/**
 * Inherits from QTable and extend its functionality.
 * @author Lumir Vanek
 */
class TableWidget : public QTable
{
		Q_OBJECT

	public:
		TableWidget( int numRows, int numCols, QWidget * parent = 0, const char * name = 0 );
		virtual ~TableWidget() {}

	public slots:
		/** Changes/Rebuilds the whole table according to the given element's attributes. */
		void slotChange( XmlElement * const );

	protected:
		/** Called, when mouse event occurs in widget */
		virtual void contentsMousePressEvent(QMouseEvent *);

	signals:
		/** Emited, when user press right mouse button */
		void sigRightButtonPressed(const QPoint&);
};

#endif
